@@ -59,6 +59,8 @@ CaptchaSettingsTab::CaptchaSettingsTab(QWidget *parent) :
     m_view->setModel(m_model);
     m_view->setRootIsDecorated(false);
     m_view->setSelectionBehavior(QTreeView::SelectRows);
+    m_view->setUniformRowHeights(true);
+    m_view->setAllColumnsShowFocus(true);
     m_view->setEditTriggers(QTreeView::NoEditTriggers);
     m_view->setExpandsOnDoubleClick(false);
     m_view->setItemsExpandable(false);
