@@ -37,11 +37,11 @@ int main(int argc, char *argv[])
     config.setProtocol(QSsl::TlsV1);
     QSslConfiguration::setDefaultConfiguration(config);
 
+    QIcon::setThemeName("Lubuntu");
+
     qRegisterMetaType< QList<Transfer*> >("QList<Transfer*>");
     qRegisterMetaType< QList<QUrl> >("QList<QUrl>");
 
-    QIcon::setThemeName("elementary-xfce");
-
     Session session;
 
     DBusServiceAdaptor adaptor(DBusService::instance());
