@@ -83,7 +83,7 @@ MainWindow::MainWindow(QWidget *parent) :
     m_model(TransferModel::instance()),
     m_filterModel(new TransferFilterModel(this)),
     m_view(new QTreeView(this)),
-    m_urlMenu(this->menuBar()->addMenu(tr("URLs"))),
+    m_urlMenu(this->menuBar()->addMenu(tr("File"))),
     m_addUrlsAction(m_urlMenu->addAction(QIcon::fromTheme("list-add"), tr("Add URLs"),
                                          this, SLOT(showAddUrlsDialog()), Qt::CTRL + Qt::Key_A)),
     m_importUrlsAction(m_urlMenu->addAction(QIcon::fromTheme("document-open"), tr("Import URLs"),
@@ -385,14 +385,13 @@ MainWindow::MainWindow(QWidget *parent) :
     this->connect(Database::instance(), SIGNAL(categoriesChanged()), this, SLOT(setCategoryMenuActions()));
     this->connect(ClipboardMonitor::instance(), SIGNAL(clipboardUrlsReady(QString)),
                   this, SLOT(showAddUrlsDialog(QString)));
-    this->connect(PluginManager::instance(), SIGNAL(busy(QString,int)), this, SLOT(showProgressDialog(QString,int)));
-    this->connect(PluginManager::instance(), SIGNAL(progressChanged(int)), this, SLOT(updateProgressDialog(int)));
     this->connect(PluginManager::instance(), SIGNAL(pluginsReady()), this, SLOT(onPluginsReady()));
-    this->connect(PluginManager::instance(), SIGNAL(pluginsReady()), this, SLOT(hideProgressDialog()));
 
     this->onWindowStateChanged();
     this->onPackageCountChanged(m_model->rowCount());
     this->setCategoryMenuActions();
+    
+    PluginManager::instance()->loadPlugins();
 }
 
 MainWindow::~MainWindow() {}
@@ -409,14 +408,6 @@ bool MainWindow::event(QEvent *event) {
     return QMainWindow::event(event);
 }
 
-void MainWindow::showEvent(QShowEvent *event) {
-    if (PluginManager::instance()->servicePlugins().isEmpty()) {
-        QTimer::singleShot(1000, PluginManager::instance(), SLOT(loadPlugins()));
-    }
-
-    QMainWindow::showEvent(event);
-}
-
 void MainWindow::dragEnterEvent(QDragEnterEvent *event) {
     if ((event->mimeData()->hasUrls()) && (event->mimeData()->urls().first().path().toLower().endsWith(".txt"))) {
         event->acceptProposedAction();
@@ -729,7 +720,7 @@ void MainWindow::pauseCurrentTransfer() {
 
 void MainWindow::removeCurrentTransfer() {
     if (m_view->currentIndex().isValid()) {
-        m_model->setData(m_filterModel->mapToSource(m_view->currentIndex()), Transfers::Cancelled, Transfer::StatusRole);
+        m_model->setData(m_filterModel->mapToSource(m_view->currentIndex()), Transfers::Canceled, Transfer::StatusRole);
     }
 }
 
@@ -801,7 +792,7 @@ void MainWindow::removeCurrentPackage() {
     if (m_view->currentIndex().isValid()) {
         m_model->setData(m_filterModel->mapToSource(m_view->currentIndex().parent().isValid() ? m_view->currentIndex().parent()
                                                                                               : m_view->currentIndex()),
-                         Transfers::Cancelled, Transfer::PackageStatusRole);
+                         Transfers::Canceled, Transfer::PackageStatusRole);
     }
 }
 
@@ -874,7 +865,7 @@ void MainWindow::retrieveUrlsFromText(const QString &text) {
     this->connect(UrlRetriever::instance(), SIGNAL(progressChanged(int)), this, SLOT(updateProgressDialog(int)));
     this->connect(UrlRetriever::instance(), SIGNAL(finished()), this, SLOT(onUrlRetrieverFinished()));
     this->connect(UrlRetriever::instance(), SIGNAL(finished()), this, SLOT(hideProgressDialog()));
-    this->connect(UrlRetriever::instance(), SIGNAL(cancelled()), this, SLOT(hideProgressDialog()));
+    this->connect(UrlRetriever::instance(), SIGNAL(canceled()), this, SLOT(hideProgressDialog()));
     UrlRetriever::instance()->parseUrlsFromText(text);
 }
 
