@@ -59,7 +59,7 @@ CheckUrlsDialog::CheckUrlsDialog(QWidget *parent) :
     grid->addWidget(m_buttonBox, 3, 0);
 
     this->connect(UrlChecker::instance(), SIGNAL(progressChanged(int)), this, SLOT(onProgressChanged(int)));
-    this->connect(UrlChecker::instance(), SIGNAL(cancelled()), this, SLOT(onCancelled()));
+    this->connect(UrlChecker::instance(), SIGNAL(canceled()), this, SLOT(onCanceled()));
     this->connect(m_buttonBox, SIGNAL(accepted()), this, SLOT(accept()));
     this->connect(m_buttonBox, SIGNAL(rejected()), UrlChecker::instance(), SLOT(cancel()));
 }
@@ -81,10 +81,10 @@ void CheckUrlsDialog::onProgressChanged(int progress) {
     }
 }
 
-void CheckUrlsDialog::onCancelled() {
+void CheckUrlsDialog::onCanceled() {
     m_okButton->setEnabled(true);
     m_cancelButton->setEnabled(false);
-    m_infoLabel->setText(QString("<i>%1</i>").arg(tr("Cancelled")));
+    m_infoLabel->setText(QString("<i>%1</i>").arg(tr("Canceled")));
 }
 
 void CheckUrlsDialog::resetDialog() {
